==> scummvm_1.0.0-3.tar.gz: scummvm-1.0.0/engines/cruise/volume.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-0-0/engines/cruise/volume.h $
 * $Id: volume.h 39791 2009-04-01 14:02:55Z lordhoto $
 *
 */

#ifndef CRUISE_VOLUME_H
#define CRUISE_VOLUME_H

namespace Cruise {

int16 readVolCnf(void);
int closeCnf(void);
int16 findFileInDisks(const char *name);
void freeDisk(void);
int16 findFileInList(const char *fileName);

////////////////

void strToUpper(char *string);
void drawMsgString(const char *string);
void askDisk(int16 discNumber);
void setObjectPosition(int16 param1, int16 param2, int16 param3, int16 param4);

int closeBase(void);

} // End of namespace Cruise

#endif

==> scummvm_1.1.0.tar.gz: scummvm-1.1.0/engines/cruise/volume.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-1-0/engines/cruise/volume.h $
 * $Id: volume.h 45616 2009-11-02 21:54:57Z fingolfin $
 *
 */

#ifndef CRUISE_VOLUME_H
#define CRUISE_VOLUME_H

namespace Cruise {

int16 readVolCnf();
int closeCnf();
int16 findFileInDisks(const char *name);
void freeDisk();
int16 findFileInList(const char *fileName);

////////////////

void strToUpper(char *string);
void drawMsgString(const char *string);
void askDisk(int16 discNumber);
void setObjectPosition(int16 param1, int16 param2, int16 param3, int16 param4);

int closeBase();

} // End of namespace Cruise

#endif
